@@ -1,3 +1,4 @@
+# Copyright 2022 Hewlett Packard Enterprise Development Company, L.P.
 # Copyright 2018 Hewlett-Packard Development Company, L.P.
 #
 # Licensed under the Apache License, Version 2.0 (the "License"); you may
@@ -34,6 +35,7 @@ from proliantutils.ilo import firmware_controller
 from proliantutils.ilo import mappings
 from proliantutils.ilo import operations
 from proliantutils import log
+from proliantutils import utils
 
 
 POWER_STATE = {
@@ -423,6 +425,10 @@ class RIBCLOperations(operations.IloOperations):
             'DEVICE': device.upper(),
             'IMAGE_URL': url,
         }
+
+        # Validate url
+        utils.validate_href(url)
+
         data = self._execute_command(
             'INSERT_VIRTUAL_MEDIA', 'RIB_INFO', 'write', dic)
         return data
@@ -1265,6 +1271,24 @@ class RIBCLOperations(operations.IloOperations):
         """
         self._raise_command_not_supported("get_bios_settings_result")
 
+    def create_csr(self, path, csr_params):
+        """Creates the Certificate Signing Request.
+
+        :param path: directory to store csr file.
+        :param csr_params: A dictionary containing all the necessary
+               information required to create CSR.
+        :raises: IloError, on an error from iLO.
+        """
+        self._raise_command_not_supported("create_csr")
+
+    def add_https_certificate(self, cert_file):
+        """Adds the signed https certificate to the iLO.
+
+        :param cert_file: Signed HTTPS certificate file.
+        :raises: IloError, on an error from iLO.
+        """
+        self._raise_command_not_supported("add_https_certificate")
+
 
 # The below block of code is there only for backward-compatibility
 # reasons (before commit 47608b6 for ris-support).
