@@ -18,9 +18,9 @@ import os
 import shutil
 import tempfile
 import unittest
+from unittest import mock
 
 import ddt
-import mock
 from six.moves import builtins as __builtin__
 
 from proliantutils import exception
@@ -467,6 +467,9 @@ class FirmwareImageExtractorTestCase(unittest.TestCase):
             'extracted_file_from_scexe',
             'extracted_file_from_rpm',
         ]
+        tempfile_mock.mkdtemp.side_effect = [
+            '/tmp', '/tmp', '/tmp'
+        ]
         # | WHEN |
         for fw_file in firmware_files:
             fw_img_extractor = firmware_controller.get_fw_extractor(fw_file)
