@@ -14,8 +14,8 @@
 """Test Class for HttpsCertTestCase"""
 
 import json
+from unittest import mock
 
-import mock
 import sushy
 import testtools
 
